/*
struct Page_Ppm
{
  GtkWidget *frame_ppm;
  GtkWidget *label_ppm;
  GtkWidget *radio_raw_ppm;
  GtkWidget *radio_ascii_ppm;
  GtkWidget *vbox_ppm;
  GSList *group_ppm;
};

struct Page_Jpeg 
{
  GtkWidget *frame_jpeg;
  GtkWidget *vbox_jpeg;
  GtkWidget *table_jpeg;
  GtkWidget *quality_jpeg;
  GtkWidget *smooth_jpeg;
  GtkWidget *label_jpeg;
  GtkWidget *optimize_jpeg;
  GtkObject *quality_adj_jpeg;
  GtkObject *smooth_adj_jpeg;
};

struct Page_Gif
{
  GtkWidget *frame_gif;
  GtkWidget *vbox_gif;
  GtkWidget *label_gif;
  GtkWidget *interlace_gif;
  GtkWidget *comment_gif;
  GtkWidget *comment_text_gif;
  GtkWidget *scrollbox_gif;
};
*/

enum Save_Types {
  PNG = 0,
  PPM = 1,
  JPEG = 2,
  GIF = 3
};

enum Ppm_Types {
  RAW = 0,
  ASCII = 1
};

void save_dialog(GtkWidget*, struct Camera*);
void file_select(GtkWidget *widget, struct Camera *camera);
void jpeg_save(struct Camera *camera);
void ppm_save(struct Camera *camera);
void png_save(struct Camera *camera);
void savefile_append_time(struct Camera *camera);
